Thug
====

|travis badge| |landscape badge| |downloads badge| |version badge|

The number of client-side attacks has grown significantly in the past few years
shifting focus on poorly protected vulnerable clients. Just as the most known
honeypot technologies enable research into server-side attacks, honeyclients
allow the study of client-side attacks.

A complement to honeypots, a honeyclient is a tool designed to mimic the behavior
of a user-driven network client application, such as a web browser, and be
exploited by an attacker's content.

Thug is a Python low-interaction honeyclient aimed at mimicing the behavior of a
web browser in order to detect and emulate malicious contents.


Documentation
-------------

Documentation about Thug installation and usage can be found in the source
tree or alternatively at https://buffer.github.com/thug/


Support
-------

* Mailing Lists
	* Thug users         https://public.honeynet.org/mailman/listinfo/thug
	* Thug development   https://public.honeynet.org/mailman/listinfo/thug-dev

* IRC
	* Freenode #thug-dev


Contributions
-------------

Thug is open source and free to use for any purpose (even commercial ones). If
you use and appreciate Thug, consider supporting the project with a donation
using Paypal (details at https://buffer.github.com/thug/).


License information
-------------------

Copyright (C) 2011-2017 Angelo Dell'Aera <angelo.dellaera@honeynet.org>

License: GNU General Public License, version 2


.. |travis badge| image:: https://img.shields.io/travis/buffer/thug/master.svg
   :target: https://travis-ci.org/buffer/thug
.. |landscape badge| image:: https://landscape.io/github/buffer/thug/master/landscape.png
   :target: https://landscape.io/github/buffer/thug/master
   :alt: Code Health
.. |downloads badge| image:: https://img.shields.io/pypi/dm/thug.svg
   :target: https://pypi.python.org/pypi/thug/
.. |version badge| image:: https://img.shields.io/pypi/v/thug.svg
   :target: https://pypi.python.org/pypi/thug/
